
// TODO: add support for spotlight ...
struct light
{
  vec3 position;
  vec4 ambient;
  vec4 diffuse;
  vec4 specular;
  
  // TODO: only directional light is supported
};

struct material_properties
{
  vec4 ambient;
  vec4 diffuse;
  vec4 specular;
  vec4 emissive;
  float shininess;
};

const float c_zero = 0.0;
const float c_one = 1.0;

// TODO add as user uniform ---
const bool normalize_normal = true;
const vec4 ambient_scene = vec4(0.0, 0.0, 0.0, 1.0);
const int num_lights = 1;
// ----------------------------

uniform material_properties u_material;
uniform light u_light0;

attribute vec4 a_position;
attribute vec3 a_normal;
attribute vec2 a_texCoord0;

varying vec2 v_texCoord0;
varying vec4 v_color0;

uniform mat4 u_matWVP;
uniform mat3 u_matWVNormals;

vec3 n;
vec4 mat_ambient;
vec4 mat_diffuse;

vec4 lighting_equation(int i)
{
  vec4 computed_color = vec4(c_zero, c_zero, c_zero, c_zero);
  vec3 h_vec;
  float ndotl, ndoth;
  float att_factor;
  
  att_factor = c_one;

  vec3 VPpli = u_light0.position.xyz;
  
  if(att_factor > c_zero)
  {
    computed_color += u_light0.ambient * mat_ambient;
    
    ndotl = max(c_zero, dot(n,VPpli));
    computed_color += (ndotl * u_light0.diffuse * mat_diffuse);
    
    /*
    // SPECULAR
    h_vec = normalize(VPpli + vec3(c_zero, c_zero, c_one));
    ndoth = dot(n, h_vec);
    
    
    if(ndoth > c_zero)
    {
      computed_color += (pow(ndoth, material.shininess) * material.specular * light0.specular);
    }
    */
    
    computed_color *= att_factor;
  }
  
  return computed_color;
}

vec4 do_lighting()
{
  vec4 vtx_color;
  int i,j;
  
  vtx_color = u_material.emissive + (mat_ambient * ambient_scene);
  
  j = 0;
  for(i = 0; i <1; i++)
  {
    if(j > num_lights)
    {
      break;
    }
    
    //if(light_enabled_state[i])
    {
      j++;
      vtx_color += lighting_equation(i);
    }
  }
  
  vtx_color.a = mat_diffuse.a;
  
  return vtx_color;
}

void main()
{
  n = u_matWVNormals * a_normal;
    
  mat_ambient = u_material.ambient;
  mat_diffuse = u_material.diffuse;
  
  v_color0 = do_lighting();
  
  gl_Position = u_matWVP * a_position;
  v_texCoord0 = a_texCoord0;
}
