varying vec2 v_texCoord0;
varying vec2 v_texCoord1;

uniform sampler2D s_texture0;
uniform sampler2D s_texture1;

uniform mat4 u_matVPInvCurr;
uniform mat4 u_matVPPrev;

uniform float u_numSamples;

void main()
{   
  // Get the depth buffer value at this pixel.  
  float zOverW = texture2D(s_texture1, v_texCoord1).x;  
  
  // H is the viewport position at this pixel in the range -1 to 1. Noramlized Device Coordinates (NDC)
  vec4 H = vec4(v_texCoord1.x * 2.0 - 1.0, (1.0 - v_texCoord1.y) * 2.0 - 1.0, zOverW, 1.0);  
  
  // Transform by the view-projection inverse.  
  vec4 D = H * u_matVPInvCurr;  
  
  // Divide by w to get the world position.  
  vec4 worldPos = D / D.w;
  
  // Current viewport position  
  vec4 currentPos = H;
  
  // Use the world position, and transform by the previous view-  
  // projection matrix.  
  vec4 previousPos = worldPos * u_matVPPrev;  
  
  // Convert to nonhomogeneous points [-1,1] by dividing by w.  
  previousPos /= previousPos.w;
   
  // Use this frame's position and last frame's to compute the pixel  
  // velocity.  
  vec2 velocity = (currentPos - previousPos).xy/2.0;
  
  velocity = clamp(velocity, vec2(), Vec2())
  
  // Get the initial color at this pixel.  
  vec4 color = texture2D(s_texture0, v_texCoord0);  
  
  vec2 texCoord = v_texCoord0;
  
  texCoord += velocity;  
  for(float i = 1.0; i < u_numSamples; i+=1.0, texCoord += velocity)  
  {  
    // Sample the color buffer along the velocity vector.  
    vec4 currentColor = texture2D(s_texture0, texCoord);  
    // Add the current color to our color sum.  
    color += currentColor;  
  } 
  
  // Average all of the samples to get the final blur color.  
  vec4 finalColor = color / u_numSamples; 
  
  gl_FragColor = finalColor;

  /*
  finalColor = vec4(0.0,0.0,0.0,1.0);
  
  if (velocity.x < 0.0)
    finalColor.r = -velocity.x * 10.0;
  else
    finalColor.g = velocity.x * 10.0;
  
  gl_FragColor = finalColor;
   */
  
  
  
}