varying vec2 v_texCoord0;
varying vec2 v_texCoord1;

uniform sampler2D s_texture0;
uniform sampler2D s_texture1;

uniform float u_numSamples;
uniform float u_velocityFactor;

void main()
{   
  float speed = texture2D(s_texture1, v_texCoord1).r;
  
  // Get the initial color at this pixel.  
  vec4 color = texture2D(s_texture0, v_texCoord0);  
  
  if (speed > 0.0 && u_velocityFactor > 0.0) 
  {
    vec2 direction = (v_texCoord1 - vec2(0.5, 0.5))*2.0;
    direction = -normalize(direction);
  
    vec2 velocity = direction*speed*u_velocityFactor;
    vec2 texCoord = v_texCoord0;
    
    texCoord += velocity;  
    for(float i = 1.0; i < u_numSamples; i+=1.0, texCoord += velocity)  
    {  
      // Sample the color buffer along the velocity vector.  
      vec4 currentColor = texture2D(s_texture0, texCoord);  
      // Add the current color to our color sum.  
      color += currentColor;  
    } 
    
    // Average all of the samples to get the final blur color.  
    gl_FragColor = color / u_numSamples; 
  }
  else
  {
    gl_FragColor = color;
  }
}